==> redquicklib-1.160.0.tgz: package/lib/components/inifinitelistselect.js <==
import React, { Component } from 'react';
import { connect } from 'react-redux';
require('../array');
// import {
//     CardIOView,
//     CardIOUtilities,
//     CardIOModule
// } from 'react-native-awesome-card-io';
import {
    Container,
    Header,
    Content,
    Footer,
    FooterTab,
    Button,
    Icon,
    List,
    ListItem,
    InputGroup,
    Input,
    Body,
    Title,
    Left,
    Right,
    Card,
    Spinner,
    CardItem,

} from 'native-base';
import * as Colors from '../colors';
import * as Common from '../common';

import {
    Text,
    KeyboardAvoidingView,
    StyleSheet,
    View,
    Platform,
    Item, Image,
    TouchableOpacity,
    Picker, Dimensions
} from 'react-native';

import * as utils from '../util';


import * as Titles from '../titles';



import { Actions } from 'react-native-router-flux';
const listpadding = 20;

class InfiniteListSelect extends Component {
    constructor(props) {
        super(props);
        this.state = {
            filter: ''
        };
    }
    render() {
        var me = this;
        var { options, inputprops } = me.props;
        return (
            <KeyboardAvoidingView behavior={'position'}>
                <View style={{ flexDirection: 'column' }}>
                    <InputGroup  {...options.errorGroupState() }>
                        {options.errorIcon()}
                        <Input
                            {...inputprops}
                            style={Object.assign(flex(), options.lightMode ? { color: Colors.Dark } : null, options.inputStyle())}
                            value={() => {
                                return me.state.filter;
                            }}
                            onChangeText={val => {
                                me.setState({
                                    filter: val
                                });
                            }}
                            placeholderTextColor={options.required() ? Colors.Danger : Colors.LighterDark}
                            placeholder={options.placeHolder + (options.required() ? '*' : '')} />

                    </InputGroup>
                    {hr_}
                    {options.errorText()}
                    <List>{
                        options.items().filter(t => {
                            return (t || t.title || '-!@#$').toLowerCase().indexOf((me.state.filter || '').toLowerCase()) !== -1;
                        }).subset(0, me.props.maxShow || 5).map(t => {
                            return (
                                <ListItem onPress={() => {
                                    if (options.onValueChange) {
                                        options.onValueChange(t);
                                        me.setState({ filter: t.name })
                                    }
                                }}>
                                    <Text>{t.title}</Text>
                                </ListItem>
                            )
                        })
                    }</List>
                </View>
            </KeyboardAvoidingView>
        );
    }
}
export default (InfiniteListSelect);

==> redquicklib-1.163.0.tgz: package/lib/components/inifinitelistselect.js <==
import React, { Component } from 'react';
import { connect } from 'react-redux';
require('../array');
// import {
//     CardIOView,
//     CardIOUtilities,
//     CardIOModule
// } from 'react-native-awesome-card-io';
import {
    Container,
    Header,
    Content,
    Footer,
    FooterTab,
    Button,
    Icon,
    List,
    ListItem,
    InputGroup,
    Input,
    Body,
    Title,
    Left,
    Right,
    Card,
    Spinner,
    CardItem,

} from 'native-base';
import * as Colors from '../colors';
import * as Common from '../common';

import {
    Text,
    KeyboardAvoidingView,
    StyleSheet,
    View,
    Platform,
    Item, Image,
    TouchableOpacity,
    Picker, Dimensions
} from 'react-native';

import * as utils from '../util';


import * as Titles from '../titles';



import { Actions } from 'react-native-router-flux';
const listpadding = 20;

class InfiniteListSelect extends Component {
    constructor(props) {
        super(props);
        this.state = {
            filter: ''
        };
    }
    render() {
        var me = this;
        var { options, inputprops } = me.props;
        var hr_ = options.hr_;
        var flex = options.flex;
        return (
            <KeyboardAvoidingView behavior={'position'}>
                <View style={{ flexDirection: 'column' }}>
                    <InputGroup  {...options.errorGroupState() }>
                        {options.errorIcon()}
                        <Input
                            {...inputprops}
                            style={Object.assign({ flex: 1 }, options.lightMode ? { color: Colors.Dark } : null, options.inputStyle())}
                            value={() => {
                                return me.state.filter;
                            }}
                            onChangeText={val => {
                                me.setState({
                                    filter: val
                                });
                            }}
                            placeholderTextColor={options.required() ? Colors.Danger : Colors.LighterDark}
                            placeholder={options.placeHolder + (options.required() ? '*' : '')} />

                    </InputGroup>
                    {hr_}
                    {options.errorText()}
                    <List>{
                        options.items().filter(t => {
                            return (t || t.title || '-!@#$').toLowerCase().indexOf((me.state.filter || '').toLowerCase()) !== -1;
                        }).subset(0, me.props.maxShow || 5).map(t => {
                            return (
                                <ListItem onPress={() => {
                                    if (options.onValueChange) {
                                        options.onValueChange(t);
                                        me.setState({ filter: t.name })
                                    }
                                }}>
                                    <Text>{t.title}</Text>
                                </ListItem>
                            )
                        })
                    }</List>
                </View>
            </KeyboardAvoidingView>
        );
    }
}
export default (InfiniteListSelect);
